"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.deleteLatestPost = exports.navigateToProfilePage = exports.loginUser = void 0;
/**
 * Logs user in
 */
const loginUser = (credentials) => (page) => __awaiter(void 0, void 0, void 0, function* () {
    const { email, password } = credentials;
    const selectors = {
        emailInput: 'input#email',
        passwordInput: 'input#pass',
        loginSubmitButton: 'button[data-testid="royal_login_button"]',
        cookiesAcceptButton: 'button[data-testid="cookie-policy-dialog-accept-button"]',
    };
    /* Accept cookies */
    yield page.waitForSelector(selectors.cookiesAcceptButton);
    yield page.click(selectors.cookiesAcceptButton);
    /* Enter email */
    yield page.focus(selectors.emailInput);
    yield page.keyboard.type(email);
    /* Enter password */
    yield page.focus(selectors.passwordInput);
    yield page.keyboard.type(password);
    /* Submit login form */
    yield Promise.all([
        page.waitForNavigation(),
        page.click(selectors.loginSubmitButton),
    ]);
});
exports.loginUser = loginUser;
/**
 * Navigates to profile page
 */
const navigateToProfilePage = (page) => __awaiter(void 0, void 0, void 0, function* () {
    yield page.goto('https://www.facebook.com/me');
});
exports.navigateToProfilePage = navigateToProfilePage;
/**
 * Deletes latest post on profile page
 */
const deleteLatestPost = (page) => __awaiter(void 0, void 0, void 0, function* () {
    const selectors = {
        optionsButton: 'div[aria-label="Actions for this post"]',
        deleteOptionButton: "//span[contains(., 'Move to trash')]",
        deleteSubmitButton: 'div[aria-label="Move"]',
        responseToast: "//span[contains(., 'Moving post to your trash')]",
    };
    /* Open post options */
    yield page.waitForSelector(selectors.optionsButton);
    yield page.evaluate((selector) => document.querySelector(selector).click(), selectors.optionsButton);
    yield page.waitForTimeout(2500);
    /* Select "Move to trash" option */
    yield page.waitForXPath(selectors.deleteOptionButton);
    const [deleteOptionButton] = yield page.$x(selectors.deleteOptionButton);
    yield deleteOptionButton.click();
    yield page.waitForTimeout(2500);
    /* Submit confirmation dialog */
    yield page.waitForSelector(selectors.deleteSubmitButton);
    yield page.evaluate((selector) => document.querySelector(selector).click(), selectors.deleteSubmitButton);
    /* Wait for "Moving post to your trash" toast */
    yield page.waitForXPath(selectors.responseToast);
});
exports.deleteLatestPost = deleteLatestPost;
//# sourceMappingURL=facebook.js.map